@@ -1,4 +1,8 @@
-=pod BOGUS
+=pod
+
+=head2 IsMoose->baz
+
+The baz method
 
 =cut
 
@@ -10,4 +14,6 @@ with 'MooseRole';
 
 sub bar { }
 
+sub baz { }
+
 1;
